/**
 * Main entry point for the React application.
 * Sets up the React app and renders it to the DOM.
 */
import { StrictMode } from 'react'
import { createRoot } from 'react-dom/client'
import './index.css'
import App from './App.tsx'

// Register service worker for better caching (production only)
if ('serviceWorker' in navigator && import.meta.env.PROD) {
  window.addEventListener('load', () => {
    navigator.serviceWorker.register('/sw.js')
      .then((registration) => {
        if (import.meta.env.DEV) {
          console.log('Service Worker registered:', registration.scope);
        }
      })
      .catch((error) => {
        if (import.meta.env.DEV) {
          console.log('Service Worker registration failed:', error);
        }
      });
  });
}

// Global error handler for uncaught script errors
window.addEventListener('error', (event) => {
  // Check for mobile script errors specifically
  const errorMessage = event.message || '';
  const errorFilename = event.filename || '';
  
  const isMobileScriptError = (
    errorMessage.includes('mobile script') ||
    errorMessage.includes('Failed to load mobile script') ||
    errorMessage.includes('applicationinsights') ||
    errorMessage.includes('script error') ||
    errorFilename.includes('mobile') ||
    errorFilename.includes('gtag') ||
    errorFilename.includes('analytics') ||
    errorFilename.includes('googletagmanager') ||
    errorFilename.includes('platform.twitter.com') ||
    errorFilename.includes('instagram.com/embed')
  );
  
  if (isMobileScriptError) {
    // Only log in development
    if (import.meta.env.DEV) {
      console.warn('Script loading error (suppressed in production):', {
        message: errorMessage,
        filename: errorFilename,
        line: event.lineno,
        column: event.colno
      });
    }
    // Prevent the error from showing in console
    event.preventDefault();
    event.stopPropagation();
    return false;
  }
  
  // Log other script errors only in development
  if (import.meta.env.DEV && errorMessage.includes('script')) {
    console.warn('Other script loading error:', errorMessage, errorFilename);
  }
});

// Handle unhandled promise rejections (for async script loading)
window.addEventListener('unhandledrejection', (event) => {
  const reason = event.reason?.toString() || '';
  const isMobileScriptError = reason.includes('mobile script') || 
                              reason.includes('Failed to load') ||
                              reason.includes('gtag') ||
                              reason.includes('analytics') ||
                              reason.includes('applicationinsights') ||
                              reason.includes('script error');
  
  if (isMobileScriptError) {
    // Only log in development
    if (import.meta.env.DEV) {
      console.warn('Script promise rejection (suppressed in production):', reason);
    }
    // Prevent the error from showing in console
    event.preventDefault();
    return false;
  }
});

// Additional error suppression for specific script errors
const originalConsoleError = console.error;
console.error = function(...args) {
  const message = args.join(' ').toLowerCase();
  
  // Check if this is a script loading error we want to suppress
  const shouldSuppress = message.includes('failed to load mobile script') ||
                        message.includes('script error') ||
                        message.includes('applicationinsights') ||
                        message.includes('gtag') ||
                        message.includes('analytics') ||
                        message.includes('platform.twitter.com') ||
                        message.includes('instagram.com/embed');
  
  if (shouldSuppress && import.meta.env.PROD) {
    // Suppress in production
    return;
  }
  
  if (shouldSuppress && import.meta.env.DEV) {
    // Log as warning in development instead of error
    console.warn('Suppressed script error:', ...args);
    return;
  }
  
  // Call original console.error for other messages
  originalConsoleError.apply(console, args);
};

// Also override console.warn for script warnings
const originalConsoleWarn = console.warn;
console.warn = function(...args) {
  const message = args.join(' ').toLowerCase();
  
  // Check if this is a script warning we want to suppress
  const shouldSuppress = message.includes('failed to load mobile script') ||
                        message.includes('script error') ||
                        message.includes('applicationinsights');
  
  if (shouldSuppress && import.meta.env.PROD) {
    // Suppress in production
    return;
  }
  
  // Call original console.warn for other messages or in development
  originalConsoleWarn.apply(console, args);
};

// Monitor script additions and add error handlers
const observer = new MutationObserver((mutations) => {
  mutations.forEach((mutation) => {
    mutation.addedNodes.forEach((node) => {
      if (node.nodeType === Node.ELEMENT_NODE && (node as Element).tagName === 'SCRIPT') {
        const script = node as HTMLScriptElement;
        
        // Add error handler to all dynamically added scripts
        script.addEventListener('error', (event) => {
          if (import.meta.env.DEV) {
            console.warn('Dynamic script loading error:', script.src);
          }
          event.stopPropagation();
          event.preventDefault();
        });
      }
    });
  });
});

// Start observing
observer.observe(document, {
  childList: true,
  subtree: true
});

// Register service worker for caching
if ('serviceWorker' in navigator && import.meta.env.PROD) {
  window.addEventListener('load', () => {
    navigator.serviceWorker.register('/sw.js')
      .then((registration) => {
        // Only log in development mode
        if (import.meta.env.DEV) {
          console.log('Service Worker registered successfully:', registration);
        }
      })
      .catch((error) => {
        // Only log service worker errors in development to avoid console spam
        if (import.meta.env.DEV) {
          console.error('Service Worker registration failed:', error);
        }
      });
  });
}

createRoot(document.getElementById('root')!).render(
  <StrictMode>
    <App />
  </StrictMode>,
)
